"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getEtherscanBaseURLForChain = exports.isAccountValidForChain = exports.isAccountValidForChainId = exports.getChainInfoByChainId = exports.getChainInfoByChain = exports.chainConfig = void 0;
const neverthrow_1 = require("neverthrow");
const businessObjects_1 = require("../businessObjects");
const index_js_1 = require("../enum/index.js");
const index_js_2 = require("../errors/index.js");
const index_js_3 = require("../primitives/index.js");
const getExplorerUrl = function (txHash) {
    return this.explorerURL + txHash;
};
exports.chainConfig = new Map([
    [
        index_js_1.EChain.DevDoodle,
        new businessObjects_1.ControlChainInformation("Dev Env Doodle Chain", (0, index_js_3.ChainId)(index_js_1.EChain.DevDoodle), index_js_1.EChain.DevDoodle, index_js_1.EChainTechnology.EVM, true, "doodlechain", 4000, new businessObjects_1.NativeCurrencyInformation("DOODLE", 18, "DOODLE"), index_js_1.EChainType.Hardhat, "", (0, index_js_3.EVMContractAddress)("0x5FC8d32690cc91D4c39d9d3abcBD16989F875707"), // Consent Contract Factory
        (0, index_js_3.EVMContractAddress)("0x610178dA211FEF7D417bC0e6FeD39F05609AD788"), // Crumbs Contract
        (0, index_js_3.EVMContractAddress)("0x9fE46736679d2D9a65F0992F2272dE9f3c7fa6e0")),
    ],
    [
        index_js_1.EChain.EthereumMainnet,
        new businessObjects_1.ChainInformation("Ethereum", (0, index_js_3.ChainId)(index_js_1.EChain.EthereumMainnet), index_js_1.EChain.EthereumMainnet, index_js_1.EChainTechnology.EVM, true, "mainnet", 10000, new businessObjects_1.NativeCurrencyInformation("ETH", 18, "ETH", "ethereum"), index_js_1.EChainType.Mainnet, "https://etherscan.io/tx/", getExplorerUrl, (0, index_js_3.URLString)("https://api.etherscan.io/")),
    ],
    [
        index_js_1.EChain.Sepolia,
        new businessObjects_1.ChainInformation("Sepolia", (0, index_js_3.ChainId)(index_js_1.EChain.Sepolia), index_js_1.EChain.Sepolia, index_js_1.EChainTechnology.EVM, true, "sepolia", 10000, new businessObjects_1.NativeCurrencyInformation("ETH", 18, "ETH", "ethereum"), index_js_1.EChainType.Testnet, "https://sepolia.etherscan.io/tx/", getExplorerUrl, (0, index_js_3.URLString)("https://api-sepolia.etherscan.io/")),
    ],
    // [
    //   ChainId(EChain.Kovan),
    //   new ChainInformation(
    //     "Kovan",
    //     ChainId(EChain.Kovan),
    //     EChain.Kovan,
    //     EChainTechnology.EVM,
    //     true,
    //     [],
    //     10000,
    //     new NativeCurrencyInformation("ETH", 18, "ETH"),
    //     EChainType.Testnet,
    //     "https://kovan.etherscan.io/tx/",
    //     getExplorerUrl,
    //   ),
    // ],
    [
        index_js_1.EChain.Mumbai,
        new businessObjects_1.ChainInformation("Mumbai", (0, index_js_3.ChainId)(index_js_1.EChain.Mumbai), index_js_1.EChain.Mumbai, index_js_1.EChainTechnology.EVM, true, "polygon-mumbai", 10000, new businessObjects_1.NativeCurrencyInformation("MATIC", 18, "MATIC", "matic-network"), index_js_1.EChainType.Testnet, "https://mumbai.polygonscan.com/tx/", getExplorerUrl, (0, index_js_3.URLString)("https://api-testnet.polygonscan.com/")),
    ],
    [
        index_js_1.EChain.Polygon,
        new businessObjects_1.ChainInformation("Polygon", (0, index_js_3.ChainId)(index_js_1.EChain.Polygon), index_js_1.EChain.Polygon, index_js_1.EChainTechnology.EVM, true, "polygon-mainnet", 10000, new businessObjects_1.NativeCurrencyInformation("MATIC", 18, "MATIC", "matic-network"), index_js_1.EChainType.Mainnet, "https=//polygonscan.com/tx/", getExplorerUrl, (0, index_js_3.URLString)("https://api.polygonscan.com/")),
    ],
    [
        index_js_1.EChain.Avalanche,
        new businessObjects_1.ChainInformation("Avalanche", (0, index_js_3.ChainId)(index_js_1.EChain.Avalanche), index_js_1.EChain.Avalanche, index_js_1.EChainTechnology.EVM, true, "avalanche-mainnet", 4000, new businessObjects_1.NativeCurrencyInformation("AVAX", 18, "AVAX", "avalanche-2"), index_js_1.EChainType.Mainnet, "https://snowtrace.io/tx/", getExplorerUrl, (0, index_js_3.URLString)("https://api.snowtrace.io/")),
    ],
    [
        index_js_1.EChain.Fuji,
        new businessObjects_1.ControlChainInformation("Fuji", (0, index_js_3.ChainId)(index_js_1.EChain.Fuji), index_js_1.EChain.Fuji, index_js_1.EChainTechnology.EVM, true, "avalanche-fuji", 4000, new businessObjects_1.NativeCurrencyInformation("AVAX", 18, "AVAX", "avalanche-2"), index_js_1.EChainType.Testnet, "https://testnet.snowtrace.io/tx/", (0, index_js_3.EVMContractAddress)("0x5540122e78241679Da8d07A04A74D3a7f52aED97"), // Consent Contract Factory
        (0, index_js_3.EVMContractAddress)("0x49a04d6545b1511742033b0ddF6a2Ba880A69287"), // Crumbs Contract
        (0, index_js_3.EVMContractAddress)("0xdB5c885944d903Ac5c146eef400D2ee20572d357"), // Metatransaction Forwarder Contract
        (0, index_js_3.URLString)("https://api-testnet.snowtrace.io/")),
    ],
    [
        index_js_1.EChain.Solana,
        new businessObjects_1.ChainInformation("Solana", (0, index_js_3.ChainId)(index_js_1.EChain.Solana), index_js_1.EChain.Solana, index_js_1.EChainTechnology.Solana, true, "solana", 400, new businessObjects_1.NativeCurrencyInformation("Sol", 9, "SOL", "solana"), index_js_1.EChainType.Mainnet, "https://explorer.solana.com/tx/", getExplorerUrl, undefined, (0, index_js_3.CoinGeckoAssetPlatformID)("solana")),
    ],
    [
        index_js_1.EChain.SolanaTestnet,
        new businessObjects_1.ChainInformation("Solana", (0, index_js_3.ChainId)(index_js_1.EChain.SolanaTestnet), index_js_1.EChain.SolanaTestnet, index_js_1.EChainTechnology.Solana, true, "solana", 400, new businessObjects_1.NativeCurrencyInformation("Sol", 9, "SOL", "solana"), index_js_1.EChainType.Testnet, "https://explorer.solana.com/tx/", getExplorerUrl, undefined, undefined),
    ],
    [
        index_js_1.EChain.Gnosis,
        new businessObjects_1.ChainInformation("Gnosis", (0, index_js_3.ChainId)(index_js_1.EChain.Gnosis), index_js_1.EChain.Gnosis, index_js_1.EChainTechnology.EVM, true, "Gnosis", 10000, // average block mining time
        new businessObjects_1.NativeCurrencyInformation("xDAI", 18, "xDAI", "xdai"), index_js_1.EChainType.Mainnet, "https://gnosisscan.io/tx/", getExplorerUrl, (0, index_js_3.URLString)("https://api.gnosisscan.io/")),
    ],
    [
        index_js_1.EChain.Binance,
        new businessObjects_1.ChainInformation("Binance", (0, index_js_3.ChainId)(index_js_1.EChain.Binance), index_js_1.EChain.Binance, index_js_1.EChainTechnology.EVM, true, "binance", 10000, // average block mining time
        new businessObjects_1.NativeCurrencyInformation("BNB", 18, "BNB", "binancecoin"), index_js_1.EChainType.Mainnet, "https://bscscan.com/tx/", getExplorerUrl, (0, index_js_3.URLString)("https://bscscan.com/")),
    ],
    [
        index_js_1.EChain.BinanceTestnet,
        new businessObjects_1.ChainInformation("Binance", (0, index_js_3.ChainId)(index_js_1.EChain.BinanceTestnet), index_js_1.EChain.BinanceTestnet, index_js_1.EChainTechnology.EVM, true, "binance", 10000, // average block mining time
        new businessObjects_1.NativeCurrencyInformation("BNB", 18, "BNB", "binancecoin"), index_js_1.EChainType.Testnet, "https://testnet.bscscan.com/tx/", getExplorerUrl, (0, index_js_3.URLString)("https://testnet.bscscan.com/")),
    ],
    [
        index_js_1.EChain.Moonbeam,
        new businessObjects_1.ChainInformation("Moonbeam", (0, index_js_3.ChainId)(index_js_1.EChain.Moonbeam), index_js_1.EChain.Moonbeam, index_js_1.EChainTechnology.EVM, true, "moonbeam", 10000, // average block mining time
        new businessObjects_1.NativeCurrencyInformation("GLMR", 18, "GLMR", "moonbeam"), index_js_1.EChainType.Mainnet, "https://moonscan.io/tx/", getExplorerUrl, (0, index_js_3.URLString)("https://api-moonbeam.moonscan.io/")),
    ],
    [
        index_js_1.EChain.Arbitrum,
        new businessObjects_1.ChainInformation("Arbitrum", (0, index_js_3.ChainId)(index_js_1.EChain.Arbitrum), index_js_1.EChain.Arbitrum, index_js_1.EChainTechnology.EVM, true, "arbitrum", 10000, // average block mining time
        new businessObjects_1.NativeCurrencyInformation("ETH", 18, "ARB", "ethereum"), index_js_1.EChainType.Mainnet, "https://arbiscan.io/tx/", getExplorerUrl, (0, index_js_3.URLString)("https://arbiscan.io/")),
    ],
    [
        index_js_1.EChain.Optimism,
        new businessObjects_1.ChainInformation("Optimism", (0, index_js_3.ChainId)(index_js_1.EChain.Optimism), index_js_1.EChain.Optimism, index_js_1.EChainTechnology.EVM, true, "optimism", 10000, // average block mining time
        new businessObjects_1.NativeCurrencyInformation("ETH", 18, "OP", "ethereum"), index_js_1.EChainType.Mainnet, "https://optimistic.etherscan.io/tx/", getExplorerUrl, (0, index_js_3.URLString)("https://api-optimistic.etherscan.io/")),
    ],
    [
        index_js_1.EChain.Astar,
        new businessObjects_1.ChainInformation("Astar", (0, index_js_3.ChainId)(index_js_1.EChain.Astar), index_js_1.EChain.Astar, index_js_1.EChainTechnology.EVM, true, "astar", 10000, // average block mining time
        new businessObjects_1.NativeCurrencyInformation("ASTR", 18, "ASTR", "astar"), index_js_1.EChainType.Mainnet, "https://astar.subscan.io/extrinsic/", getExplorerUrl, (0, index_js_3.URLString)("https://astar.subscan.io/")),
    ],
    [
        index_js_1.EChain.Sui,
        new businessObjects_1.ChainInformation("Sui", (0, index_js_3.ChainId)(index_js_1.EChain.Sui), index_js_1.EChain.Sui, index_js_1.EChainTechnology.Sui, true, "sui", 10000, // average block mining time
        new businessObjects_1.NativeCurrencyInformation("SUI", 9, "SUI", "sui"), index_js_1.EChainType.Mainnet, "https://suiexplorer.com/", getExplorerUrl, (0, index_js_3.URLString)("https://suiscan.xyz/")),
    ],
    [
        index_js_1.EChain.Shibuya,
        new businessObjects_1.ChainInformation("Shibuya", (0, index_js_3.ChainId)(index_js_1.EChain.Shibuya), index_js_1.EChain.Shibuya, index_js_1.EChainTechnology.EVM, true, "shibuya", 10000, // average block mining time
        new businessObjects_1.NativeCurrencyInformation("SBY", 18, "ASTR", "shibuya"), index_js_1.EChainType.Testnet, "https://shibuya.subscan.io/extrinsic/", getExplorerUrl, (0, index_js_3.URLString)("https://shibuya.subscan.io/")),
    ],
    [
        index_js_1.EChain.ZkSyncEra,
        new businessObjects_1.ChainInformation("zkSync Era", (0, index_js_3.ChainId)(index_js_1.EChain.ZkSyncEra), index_js_1.EChain.ZkSyncEra, index_js_1.EChainTechnology.EVM, true, "zksync-era", 10000, // average block mining time
        new businessObjects_1.NativeCurrencyInformation("ETH", 18, "ETH", "ethereum"), index_js_1.EChainType.Mainnet, "https://explorer.zksync.io/tx/", getExplorerUrl, (0, index_js_3.URLString)("https://block-explorer-api.mainnet.zksync.io/")),
    ],
    [
        index_js_1.EChain.Base,
        new businessObjects_1.ChainInformation("Base", (0, index_js_3.ChainId)(index_js_1.EChain.Base), index_js_1.EChain.Base, index_js_1.EChainTechnology.EVM, true, "base", 10000, // average block mining time
        new businessObjects_1.NativeCurrencyInformation("ETH", 18, "ETH", "ethereum"), index_js_1.EChainType.Mainnet, "https://basescan.org/tx/", getExplorerUrl, (0, index_js_3.URLString)("https://api.basescan.org/api")),
    ],
    [
        index_js_1.EChain.Chiliz,
        new businessObjects_1.ChainInformation("Chiliz", (0, index_js_3.ChainId)(index_js_1.EChain.Chiliz), index_js_1.EChain.Chiliz, index_js_1.EChainTechnology.EVM, true, "chiliz", 10000, // average block mining time
        new businessObjects_1.NativeCurrencyInformation("CHZ", 18, "CHZ", "chiliz"), index_js_1.EChainType.Mainnet, "https://scan.chiliz.com/tx/", getExplorerUrl, (0, index_js_3.URLString)("https://scan.chiliz.com/api/eth-rpc")),
    ],
]);
function getChainInfoByChain(chain) {
    const chainInfo = exports.chainConfig.get(chain);
    if (chainInfo == null) {
        throw new Error(`Unknown chain ${chain}`);
    }
    return chainInfo;
}
exports.getChainInfoByChain = getChainInfoByChain;
function getChainInfoByChainId(chainId) {
    const chainInfo = exports.chainConfig.get(chainId);
    if (chainInfo == null) {
        throw new Error(`Unknown chain id ${chainId}`);
    }
    return chainInfo;
}
exports.getChainInfoByChainId = getChainInfoByChainId;
function isAccountValidForChainId(chainId, account) {
    // Goerli is deprecated, but still supported (exists). Will throw an error while
    // A query being processed.
    if (chainId === 5)
        return false;
    const targetChainInfo = getChainInfoByChainId(chainId);
    const accountChainInfo = getChainInfoByChain(account.sourceChain);
    return targetChainInfo.chainTechnology == accountChainInfo.chainTechnology;
}
exports.isAccountValidForChainId = isAccountValidForChainId;
function isAccountValidForChain(chain, account) {
    const targetChainInfo = getChainInfoByChain(chain);
    const accountChainInfo = getChainInfoByChain(account.sourceChain);
    return targetChainInfo.chainTechnology == accountChainInfo.chainTechnology;
}
exports.isAccountValidForChain = isAccountValidForChain;
function getEtherscanBaseURLForChain(chain) {
    try {
        const chainInfo = getChainInfoByChain(chain);
        if (chainInfo.etherscanEndpointURL == undefined) {
            return (0, neverthrow_1.errAsync)(new index_js_2.AccountIndexingError("no etherscan endpoint for chainID", chain));
        }
        return (0, neverthrow_1.okAsync)(chainInfo.etherscanEndpointURL);
    }
    catch (e) {
        return (0, neverthrow_1.errAsync)(new index_js_2.AccountIndexingError("error fetching chain information", e));
    }
}
exports.getEtherscanBaseURLForChain = getEtherscanBaseURLForChain;
//# sourceMappingURL=chains.config.js.map