import { ResultAsync } from "neverthrow";
import { TokenAddress, TokenInfo, TokenMarketData } from "../businessObjects/index.js";
import { EChain } from "../enum/index.js";
import { AccountIndexingError, AjaxError, PersistenceError } from "../errors";
import { ChainId, UnixTimestamp } from "../primitives/index.js";
export interface ITokenPriceRepository {
    getTokenInfo(chain: EChain, contractAddress: TokenAddress): ResultAsync<TokenInfo | null, AccountIndexingError>;
    addTokenInfo(info: TokenInfo): ResultAsync<void, PersistenceError>;
    getTokenPrice(chain: EChain, contractAddress: TokenAddress, timestamp: UnixTimestamp): ResultAsync<number, AccountIndexingError>;
    getTokenMarketData(ids: string[]): ResultAsync<TokenMarketData[], AccountIndexingError>;
    getMarketDataForTokens(tokens: {
        chain: ChainId;
        address: TokenAddress | null;
    }[]): ResultAsync<Map<`${ChainId}-${TokenAddress}`, TokenMarketData>, AccountIndexingError | AjaxError>;
    getTokenInfoFromList(contractAddress: TokenAddress): CoinGeckoTokenInfo | undefined;
}
export declare const ITokenPriceRepositoryType: unique symbol;
export interface CoinGeckoTokenInfo {
    id: string;
    symbol: string;
    name: string;
    protocols: string[];
}
//# sourceMappingURL=ITokenPriceRepository.d.ts.map